pub struct EventRow {
pub block_number: u64,
pub transaction_index: u32,
pub log_index: u32,
pub batch_index: Option<u32>,
pub timestamp: Option<u64>,
}Expand description
Defines the minimum columns any event row must have for cursor-based pagination. These values are important for determining cursor position in result sets.
Fields
block_number: u64transaction_index: u32log_index: u32batch_index: Option<u32>timestamp: Option<u64>Trait Implementations
Sourceimpl<'de> Deserialize<'de> for EventRow
impl<'de> Deserialize<'de> for EventRow
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more