pub struct PagedResult<TRow>{
pub limit: u32,
pub size: u32,
pub first_cursor: Option<Cursor>,
pub last_cursor: Option<Cursor>,
pub sort_order: SortOrder,
pub has_more: bool,
pub results: Vec<TRow>,
}Expand description
Result of a paginated query
Fields
limit: u32The number of results that were requested
size: u32The number of results that were returned
first_cursor: Option<Cursor>If the query returned results, this will be the cursor for the first result
last_cursor: Option<Cursor>If the query returned results, this will be the cursor for the last result
sort_order: SortOrderThe sort order of the results
has_more: boolWhether there are more results available
results: Vec<TRow>The results of the query
Implementations