pub struct WrappedTokenInfo {
pub amount: U256,
pub token_type: String,
}Expand description
Information about a wrapped token found in a transfer path Maps wrapper address to [amount used in path, wrapper type]
Fields
amount: U256Amount of the wrapped token used in the path
token_type: StringThe type of wrapper (e.g., ‘CrcV2_ERC20WrapperDeployed_Demurraged’ or ‘CrcV2_ERC20WrapperDeployed_Inflationary’)