pub struct AvatarInfo {Show 17 fields
pub block_number: u64,
pub timestamp: Option<u64>,
pub transaction_index: u32,
pub log_index: u32,
pub transaction_hash: TxHash,
pub version: u32,
pub avatar_type: AvatarType,
pub avatar: Address,
pub token_id: Option<U256>,
pub has_v1: bool,
pub v1_token: Option<Address>,
pub cid_v0_digest: Option<String>,
pub cid_v0: Option<String>,
pub v1_stopped: Option<bool>,
pub is_human: bool,
pub name: Option<String>,
pub symbol: Option<String>,
}Expand description
Avatar information Contains basic information about a Circles avatar.
Fields
block_number: u64The block number of the event
timestamp: Option<u64>The timestamp of the last change to the avatar Note: May be undefined for some avatars
transaction_index: u32The transaction index
log_index: u32The log index
transaction_hash: TxHashThe hash of the transaction that last changed the avatar
version: u32If the avatar is currently active in version 1 or 2
Note: An avatar that’s active in v2 can still have a v1 token. See has_v1 and v1_token.
avatar_type: AvatarTypeThe type of the avatar
avatar: AddressThe address of the avatar
token_id: Option<U256>The personal or group token address (v1) or tokenId (v2) Note: v1 tokens are erc20 and have a token address. v2 tokens are erc1155 and have a tokenId. The v2 tokenId is always an encoded version of the avatar address.
has_v1: boolIf the avatar is signed up at v1
v1_token: Option<Address>If the avatar has a v1 token, this is the token address
cid_v0_digest: Option<String>The bytes of the avatar’s metadata cidv0
cid_v0: Option<String>The CIDv0 of the avatar’s metadata (profile)
v1_stopped: Option<bool>If the avatar is stopped in v1 Note: This is only set during Avatar initialization.
is_human: boolIndicates whether the entity is a human
name: Option<String>Groups have a name
symbol: Option<String>Groups have a symbol